@@ -7,7 +7,6 @@ from typing import Literal
 
 from tkdev.devicon import Icon_Empty, Icon_Folder, Icon_Info, Icon_Error, Icon_Warring, Icon_Question, Icon_Questhead, Icon_Hourglass, Icon_QuickFish, Icon_TkinterDev
 from tkdev.devresize import DevResize
-from tkdev.devnet import WindowEffect
 from tkdev.devcore import DevAction, DevSysTray
 from tkdev.devdraw import DrawButton
 from tkdev.devpre import DevPreToolbox
@@ -1048,5 +1047,5 @@ class DevTooltip(DevToplevel):
 
 if __name__ == '__main__':
     Window = DevWindow()
-    DevPreTooltip(Window, Window, message="我是一个工具提示", after=0)
+    DevTooltip(Window, Window, message="我是一个工具提示", after=0)
     Window.mainloop()
\ No newline at end of file
